<?xml version="1.0" ?>

<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/TR/WD-xsl"
	xmlns:xhtml="http://www.w3.org/1999/xhtml">

<xsl:template match="/">
	<html>
		<head>
			<title>
				<xsl:value-of select="list/@name"/>
			</title>
			<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
			<!-- remove or modify the base element below if generating html for a web site -->
			<xsl:if test="list/properties/links">
				<base>
					<xsl:attribute name="href">
						<xsl:value-of select="list/properties/links/@path"/>
					</xsl:attribute>
				</base>
			</xsl:if>
		</head>
    <body>
		<table border="0" cellpadding="2" cellspacing="0">
			<caption>
				<xsl:value-of select="list/@name"/>
			</caption>
		<thead>
			<!-- create the column headers -->
			<tr bgcolor="#eeeeee" align="left">
				<xsl:for-each select="list/columns/columndef">
					<th>
						<xsl:attribute name="width">
							<xsl:value-of select="@width"/>
						</xsl:attribute>
						<xsl:value-of select="@name" />
					</th>
				</xsl:for-each>
			</tr>
		</thead>
		<tbody>
			<!-- generate a row for each item in the list -->
			<xsl:for-each select="list/items/item">
				<tr valign="top">
					<!-- set background to the highlight color -->
					<xsl:if test=".[@highlight!='none']">
						<xsl:attribute name="bgcolor">
							<xsl:choose>
								<xsl:when test=".[@highlight='yellow']">#ffff99</xsl:when>
								<xsl:when test=".[@highlight='blue']">#99ffff</xsl:when>
								<xsl:when test=".[@highlight='magenta']">#ff99ff</xsl:when>
								<xsl:when test=".[@highlight='green']">#99ff99</xsl:when>
								<xsl:otherwise>#ffffff</xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
					</xsl:if>

					<!-- generate the columns for this item -->
					<xsl:for-each select="column">
						<td>
							<!-- check for type of column -->
							<xsl:choose>
								<!-- look for yesno and check box columns -->
								<xsl:when test="/list/columns/columndef[@id=context()/@columnid][(@type='yesno') or (@type='checkbox')]">
									<xsl:element name="input">
										<xsl:attribute name="type">checkbox</xsl:attribute>
										<xsl:if test=".[value='1']">
											<xsl:attribute name="checked">checked</xsl:attribute>
										</xsl:if>
									</xsl:element>
								</xsl:when>
								<!-- look for linked column -->
								<xsl:when test="/list/columns/columndef[@id=context()/@columnid][@type='linked']">
									<a>
										<xsl:attribute name="href"><xsl:value-of select="value"/></xsl:attribute>
										<xsl:value-of select="value"/>
									</a>
								</xsl:when>
								<!-- look for date columns -->
								<xsl:when test="/list/columns/columndef[@id=context()/@columnid][@type='date']">
									<xsl:if test=".[value='']">&#160;</xsl:if>
									<xsl:value-of select="display"/>
								</xsl:when>
								<!-- look for formatted notes column -->
								<xsl:when test="value[@format='lpml']">
									<xsl:apply-templates select="value/xhtml:div"/>
								</xsl:when>
								<!-- all other columns are text -->
								<xsl:otherwise>
									<!-- check for item field and indented item -->
									<xsl:if test=".[(@columnid='c16') and (../@indent &gt; 0)]">
										<table align="left" border="0" cellpadding="0" cellspacing="0">
											<tr>
												<td>
													<xsl:attribute name="width"><xsl:value-of select="number(../@indent)"/>0</xsl:attribute>&#160;</td>
											</tr>
										</table>
									</xsl:if>
									<!-- check for numbering on item field -->
									<xsl:if test=".[@columnid='c16']">
										<xsl:if test="/list/properties[@numbers='true']"><xsl:value-of select="../@order"/>. </xsl:if>
									</xsl:if>
									<!-- if blank, make sure it contains something -->
									<xsl:if test=".[value='']">&#160;</xsl:if>
									<!-- this actually puts the data in for this column -->
									<xsl:value-of select="value"/>
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</xsl:for-each>
				</tr>
			</xsl:for-each>
		</tbody>
		</table>
		<h5>
			This list was generated by <em>Ilium Software ListPro</em>.<br />
			<a href="http://www.iliumsoft.com/listpro">www.iliumsoft.com/listpro</a>
		</h5>
	</body>
    </html>
</xsl:template>

<!-- These templates are for translating formatted Notes fields to html -->
	
<!-- This template performs the identity transform for most of the nodes in the Notes field -->	
<xsl:template match="@* | node()">
	<xsl:copy><xsl:apply-templates select="@* | node()"/></xsl:copy>
</xsl:template>

<!-- This template handles elements known to be empty, so they (mostly) don't end up
	 with separate closing tags (elements with attributes still end up with closing tags) -->
<xsl:template match="xhtml:area|xhtml:basefont|xhtml:br|xhtml:col|xhtml:hr|xhtml:img|xhtml:input">
	<xsl:copy><xsl:apply-templates select="@*"/></xsl:copy>
</xsl:template>

<!-- This template translates the 'tab' element to something valid in html -->
<xsl:template match="tab" xmlns="http://www.w3.org/1999/xhtml">
	<span class="tab">&#009;</span>
</xsl:template>

</xsl:stylesheet>
