<?xml version="1.0" ?>

<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xhtml="http://www.w3.org/1999/xhtml">

<xsl:output method="xml" encoding="utf-8"/>

<xsl:template match="/">
	<rss version="2.0"
		xmlns:lp="http://www.iliumsoft.com/namespaces/listpro/rss_listpro_extensions.html"
		xmlns:dt="urn:schemas-microsoft-com:datatypes">
		<channel>
			<title><xsl:value-of select="list/@name"/></title>
			<description><xsl:value-of select="list/properties/note"/></description>
			<!-- put the link to your website here: -->
			<!-- <link>http://www.iliumsoft.com/listcasting</link> -->
			<generator>Ilium Software ListPro</generator>
			<ttl>1440</ttl>
			<docs>http://blogs.law.harvard.edu/tech/rss</docs>
			<language>en-us</language>
			
			<lp:columns>
				<!-- generate the columns for this list -->
				<xsl:for-each select="list/columns/columndef">
					<lp:columndef>
						<xsl:for-each select="@*">
							<xsl:attribute name="{name()}"><xsl:value-of select="."/></xsl:attribute>
						</xsl:for-each>
						<xsl:if test="font">
							<lp:font>
								<xsl:for-each select="font/@*">
									<xsl:attribute name="{name()}"><xsl:value-of select="."/></xsl:attribute>
								</xsl:for-each>
							</lp:font>
						</xsl:if>
					</lp:columndef>
				</xsl:for-each>
			</lp:columns>
		
			<!-- generate a row for each item in the list -->
			<xsl:for-each select="list/items/item">
				<item>
					<!-- generate the columns for this item -->
					<xsl:for-each select="column">
						<!-- check for type of column -->
						<xsl:choose>
							<!-- look for the item column -->
							<xsl:when test="@columnid='c16'">
								<title><xsl:value-of select="value"/></title>
							</xsl:when>
							<!-- look for the notes column -->
							<xsl:when test="@columnid='c64'">
								<description><xsl:value-of select="value"/></description>
								<body xmlns="http://www.w3.org/1999/xhtml">
									<xsl:apply-templates select="value/xhtml:div" mode="lpml"/>
								</body>
							</xsl:when>
							<!-- look for other columns with known names -->
							<xsl:when test="/list/columns/columndef[@id=current()/@columnid][@name='link']">
								<xsl:if test="value!=''"><link><xsl:value-of select="value"/></link></xsl:if>
							</xsl:when>
							<xsl:when test="/list/columns/columndef[@id=current()/@columnid][@name='pubDate']">
								<xsl:choose>
									<xsl:when test="altvalue[@format='rfc822']">
										<pubDate><xsl:value-of select="altvalue[@format='rfc822']"/></pubDate>
									</xsl:when>
									<xsl:when test="value!=''">
										<pubDate><xsl:value-of select="value"/></pubDate>
									</xsl:when>
								</xsl:choose>
							</xsl:when>
							<xsl:when test="/list/columns/columndef[@id=current()/@columnid][@name='guid']">
								<xsl:if test="value!=''">
									<guid>
										<xsl:attribute name="isPermaLink">
											<xsl:choose>
												<xsl:when test="/list/columns/columndef[@id=current()/@columnid][@type='linked']">true</xsl:when>
												<xsl:otherwise>false</xsl:otherwise>
											</xsl:choose>
										</xsl:attribute>
										<xsl:value-of select="value"/>
									</guid>
								</xsl:if>
							</xsl:when>
							<xsl:when test="/list/columns/columndef[@id=current()/@columnid][@name='author']">
								<xsl:if test="value!=''"><author><xsl:value-of select="value"/></author></xsl:if>
							</xsl:when>
							<xsl:when test="/list/columns/columndef[@id=current()/@columnid][@name='category']">
								<xsl:if test="value!=''"><category><xsl:value-of select="value"/></category></xsl:if>
							</xsl:when>
							<xsl:when test="/list/columns/columndef[@id=current()/@columnid][@name='comments']">
								<xsl:if test="value!=''"><comments><xsl:value-of select="value"/></comments></xsl:if>
							</xsl:when>
							<!-- all other columns use the lp:column element -->
							<xsl:otherwise>
								<xsl:if test="value!=''">
									<xsl:element name="lp:column">
										<xsl:attribute name="name">
											<xsl:value-of select="/list/columns/columndef[@id=current()/@columnid]/@name"/>
										</xsl:attribute>
										<xsl:value-of select="value"/>
									</xsl:element>
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<!-- if there is no guid column, generate the element from the unique id -->
					<xsl:if test="not(/list/columns/columndef[@name='guid'])">
						<guid isPermaLink="false"><xsl:value-of select="@uid"/></guid>
					</xsl:if>
					<!-- generate the item info for this item -->
					<xsl:if test="(@indent and (@indent &gt; 0)) or (@highlight and (@highlight != 'none'))">
						<lp:itemproperties>
							<xsl:if test="@indent and (@indent &gt; 0)">
								<xsl:attribute name="indent"><xsl:value-of select="@indent"/></xsl:attribute>
							</xsl:if>
							<xsl:if test="@highlight and (@highlight != 'none')">
								<xsl:attribute name="highlight"><xsl:value-of select="@highlight"/></xsl:attribute>
							</xsl:if>
						</lp:itemproperties>
					</xsl:if>
				</item>
			</xsl:for-each>
			
		</channel>
	</rss>
</xsl:template>

<!-- These templates are for translating formatted Notes fields to html -->
	
<!-- This template performs the identity transform for most of the nodes in the Notes field -->	
<xsl:template match="@* | node()" mode="lpml">
	<xsl:copy>
		<xsl:apply-templates select="@* | node()" mode="lpml"/>
	</xsl:copy>
</xsl:template>

<!-- This template handles elements known to be empty, so they don't end up
	 with separate closing tags -->
<xsl:template match="xhtml:area|xhtml:basefont|xhtml:br|xhtml:col|xhtml:hr|xhtml:img|xhtml:input" mode="lpml">
	<xsl:copy-of select="."/>
</xsl:template>

<!-- This template translates the 'tab' element to something valid in html -->
<xsl:template match="tab" mode="lpml"  xmlns="http://www.w3.org/1999/xhtml">
	<span class="tab"><xsl:text>&#009;</xsl:text></span>
</xsl:template>

</xsl:stylesheet>
